# Welcome to seaduck

Seaduck is a python package that helps you interpolate in an ocean dataset in both Eulerian and Lagrangian perspectives. Accessing ocean datasets with seaduck is as simple as throwing rubber ducks in the bathtub.

"What have you cute duckling found down there? "

"..."

Check out the content pages bundled with this sample book to see more.

```{tableofcontents}
```
